@@ -55,7 +55,7 @@ class PluginBase:
         self._hosts_cache = {}
         self._service_cache = {}
         self._vulns_cache = {}
-        self.start_date = datetime.now()
+        self.start_date = datetime.utcnow()
         self.logger = logger.getChild(self.__class__.__name__)
         self.open_options = {"mode": "r", "encoding": "utf-8"}
         self.plugin_version = "0.0"
@@ -509,7 +509,7 @@ class PluginBase:
     def get_data(self):
         self.vulns_data["command"]["tool"] = self.id
         self.vulns_data["command"]["command"] = self.command if self.command else self.id
-        self.vulns_data["command"]["duration"] = (datetime.now() - self.start_date).microseconds
+        self.vulns_data["command"]["duration"] = (datetime.utcnow() - self.start_date).microseconds
         return self.vulns_data
 
     def get_json(self):
@@ -589,16 +589,19 @@ class PluginXMLFormat(PluginByExtension):
     def __init__(self, ignore_info=False):
         super().__init__(ignore_info)
         self.identifier_tag = []
+        self.identifier_tag_attributes = {}
         self.extension = ".xml"
         self.open_options = {"mode": "rb"}
 
-    def report_belongs_to(self, main_tag="", **kwargs):
+    def report_belongs_to(self, main_tag="", main_tag_attributes={}, **kwargs):
         match = False
         if super().report_belongs_to(**kwargs):
             if type(self.identifier_tag) == str:
                 match = (main_tag == self.identifier_tag)
             elif type(self.identifier_tag) == list:
                 match = (main_tag in self.identifier_tag)
+            if self.identifier_tag_attributes:
+                match = self.identifier_tag_attributes.issubset(main_tag_attributes)
             self.logger.debug("Tag Match: [%s =/in %s] -> %s", main_tag, self.identifier_tag, match)
         return match
 
